﻿using Android.App;
using Android.Widget;
using Android.OS;
using Com.Syncfusion.Schedule;
using Com.Syncfusion.Schedule.Enums;
using Java.Util;
using System;
using Android.Graphics;
using Android.Util;
using Android.Nfc;
using System.Collections.ObjectModel;

namespace ScheduleAppointments_Android
{
    [Activity(Label = "ScheduleAppointments", MainLauncher = true, Icon = "@mipmap/icon")]
    public class MainActivity : Activity
    {
        /// <summary>
        /// The schedule.
        /// </summary>
        private SfSchedule schedule;

        /// <summary>
        /// The remote data.
        /// </summary>
        private ObservableCollection<CalendarEvent> remoteData;

        protected override void OnCreate(Bundle savedInstanceState)
        {
            base.OnCreate(savedInstanceState);
            //Initializing schedule
            schedule = new SfSchedule(this);
            schedule.ScheduleView = ScheduleView.MonthView;
            schedule.MonthViewSettings.ShowAppointmentsInline = true;

            remoteData = new ObservableCollection<CalendarEvent>();

            //Mock Remote Data
            CalendarEvent scheduleEvent = new CalendarEvent();
            scheduleEvent.start = "2017-08-1T09:30:41.7752486-07:00";
            scheduleEvent.end = "2017-08-1T12:30:41.7752486-07:00";
			scheduleEvent.color = "#FF0000";
            scheduleEvent.title = "schedule event";
            scheduleEvent.allDay = true;
            remoteData.Add(scheduleEvent);

            //Adding appointments
            schedule.Appointments = CreateCalendarEvents(remoteData);

            // Set our view from the "main" layout resource
            SetContentView(schedule);
        }

        protected internal ScheduleAppointmentCollection CreateCalendarEvents(ObservableCollection<CalendarEvent> _remoteData)
		{
			var Meetings = new ScheduleAppointmentCollection();
			ScheduleAppointment meeting = new ScheduleAppointment();
			Calendar calendar = Calendar.Instance;
			Calendar startTimeCalendar = Calendar.Instance;
			foreach (var calendarEvent in _remoteData)
			{
				var DefaultHour = 9;
				if (!string.IsNullOrEmpty(calendarEvent.start) && !string.IsNullOrEmpty(calendarEvent.end))
				{
					var startDate = GetDate(calendarEvent.start);
					var startYear = startDate.Year;
					var startMonth = startDate.Month;
					var startDay = startDate.Day;
					var startTime = GetDate(calendarEvent.start);

					var startHour = startTime.Hour == 0 ? DefaultHour : startTime.Hour;
					var startMinute = startTime.Minute;
					var endDate = GetDate(calendarEvent.end);
					var endYear = endDate.Year;
					var endMonth = endDate.Month;
					var endDay = endDate.Day;
					var endTime = GetDate(calendarEvent.end);
					var endHour = endTime.Hour == 0 ? DefaultHour : endTime.Hour;
					var endMinute = endTime.Minute;

					// startTimeCalendar.Set(calendar.Get(CalendarField.Year), calendar.Get(CalendarField.Month), calendar.Get(CalendarField.Date), hour, 0);

					startTimeCalendar.Set(startYear, startMonth, calendar.Get(CalendarField.Date), startHour, startMinute, 0);
					meeting.StartTime = startTimeCalendar;
					Calendar endTimeCalendar = Calendar.Instance;
					endTimeCalendar.Set(endYear, endMonth, calendar.Get(CalendarField.Date), endHour, endMinute, 0);
					meeting.EndTime = endTimeCalendar;
					meeting.Color = GetColor(calendarEvent.color);
					meeting.Subject = calendarEvent.title ?? "";
					meeting.IsAllDay = calendarEvent.allDay;
					meeting.Notes = calendarEvent.title ?? "";
					Meetings.Add(meeting);
				}
			}
            return Meetings;
		}

		private int GetColor(string color)
		{
			var defaultColor = "#086A87";
			try
			{
				if (!string.IsNullOrEmpty(color))
				{
					return Color.ParseColor(color);
				}
				return Color.ParseColor(defaultColor);
			}
			catch (Exception ex)
			{
				//Log.Debug(Tag, ex.StackTrace);
				return Color.ParseColor(defaultColor);
			}
		}
		
        private DateTimeOffset GetDate(string date)
		{

			try
			{

				if (!string.IsNullOrEmpty(date))
				{
					return DateTime.Parse(date);
				}
				else
				{
					return DateTime.UtcNow.AddHours(5).AddMinutes(45);
				}

			}
			catch (Exception e)
			{
				var dateTime = DateTimeOffset.Parse(date, System.Globalization.CultureInfo.InvariantCulture);
				return dateTime;
			}
		}
    }

    /// <summary>
    /// Calendar event.
    /// </summary>
    public class CalendarEvent
    {
        /// <summary>
        /// Gets or sets the start.
        /// </summary>
        /// <value>The start.</value>
        public string start
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the end.
        /// </summary>
        /// <value>The end.</value>
		public string end
		{
			get;
			set;
		}

        /// <summary>
        /// Gets or sets the title.
        /// </summary>
        /// <value>The title.</value>
		public string title
		{
			get;
			set;
		}

        /// <summary>
        /// Gets or sets the color.
        /// </summary>
        /// <value>The color.</value>
		public string color
		{
			get;
			set;
		}

        /// <summary>
        /// Gets or sets a value indicating whether this <see cref="T:ScheduleAppointments_Android.CalendarEvent"/> all day.
        /// </summary>
        /// <value><c>true</c> if all day; otherwise, <c>false</c>.</value>
		public bool allDay
		{
			get;
			set;
		}
    }
}

